@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 module TTFunk
   class Table
     class Cmap < Table
@@ -24,10 +26,8 @@ module TTFunk
 
       def parse!
         @version, table_count = read(4, 'nn')
-        @tables = []
-
-        table_count.times do
-          @tables << Cmap::Subtable.new(file, offset)
+        @tables = Array.new(table_count) do
+          Cmap::Subtable.new(file, offset)
         end
       end
     end
