@@ -1,10 +1,8 @@
-require_relative '../../encoding/mac_roman'
-require_relative '../../encoding/windows_1252'
+# frozen_string_literal: true
 
 module TTFunk
   class Table
     class Cmap
-
       module Format00
         attr_reader :language
         attr_reader :code_map
@@ -20,17 +18,17 @@ module TTFunk
           glyph_indexes = Array.new(256, 0)
           glyph_map = { 0 => 0 }
 
-          new_map = charmap.keys.sort.inject({}) do |map, code|
+          new_map = charmap.keys.sort.each_with_object({}) do |code, map|
             glyph_map[charmap[code]] ||= next_id += 1
-            map[code] = { :old => charmap[code], :new => glyph_map[charmap[code]] }
+            map[code] = { old: charmap[code], new: glyph_map[charmap[code]] }
             glyph_indexes[code] = glyph_map[charmap[code]]
             map
           end
 
           # format, length, language, indices
-          subtable = [0, 262, 0, *glyph_indexes].pack("nnnC*")
+          subtable = [0, 262, 0, *glyph_indexes].pack('nnnC*')
 
-          { :charmap => new_map, :subtable => subtable, :max_glyph_id => next_id+1 }
+          { charmap: new_map, subtable: subtable, max_glyph_id: next_id + 1 }
         end
 
         def [](code)
@@ -43,12 +41,11 @@ module TTFunk
 
         private
 
-          def parse_cmap!
-            @language = read(4, "x2n")
-            @code_map = read(256, "C*")
-          end
+        def parse_cmap!
+          @language = read(4, 'x2n')
+          @code_map = read(256, 'C*')
+        end
       end
-
     end
   end
 end
