@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require_relative '../table'
 
 module TTFunk
@@ -11,13 +13,13 @@ module TTFunk
       # * :table - a string representing the encoded 'glyf' table containing
       #   the given glyphs.
       # * :offsets - an array of offsets for each glyph
-      def self.encode(glyphs, new2old, old2new)
-        result = { table: '', offsets: [] }
+      def self.encode(glyphs, new_to_old, old_to_new)
+        result = { table: +'', offsets: [] }
 
-        new2old.keys.sort.each do |new_id|
-          glyph = glyphs[new2old[new_id]]
+        new_to_old.keys.sort.each do |new_id|
+          glyph = glyphs[new_to_old[new_id]]
           result[:offsets] << result[:table].length
-          result[:table] << glyph.recode(old2new) if glyph
+          result[:table] << glyph.recode(old_to_new) if glyph
         end
 
         # include an offset at the end of the table, for use in computing the
@@ -39,14 +41,13 @@ module TTFunk
 
         parse_from(offset + index) do
           raw = io.read(size)
-          number_of_contours, x_min, y_min, x_max, y_max =
-            raw.unpack('n5').map { |i| to_signed(i) }
+          number_of_contours = to_signed(raw.unpack1('n'))
 
           @cache[glyph_id] =
             if number_of_contours == -1
-              Compound.new(raw, x_min, y_min, x_max, y_max)
+              Compound.new(glyph_id, raw)
             else
-              Simple.new(raw, number_of_contours, x_min, y_min, x_max, y_max)
+              Simple.new(glyph_id, raw)
             end
         end
       end
@@ -63,4 +64,5 @@ module TTFunk
 end
 
 require_relative 'glyf/compound'
+require_relative 'glyf/path_based'
 require_relative 'glyf/simple'
